<?php
namespace AustraliaPost\Extensions\Business\Features;


use AustraliaPost\Extensions\Business\Endpoints\Create_Shipments_Endpoint;

class Tracking_Number_In_Orders_Page {

	const COLUMN_NAME = 'shipment_tracking';

	private $tracking_url =  'https://auspost.com.au/parcels-mail/track.html#/track?id={tracking_number}';

	/**
	 * The single instance of the class.
	 *
	 * @var Tracking_Number_In_Orders_Page
	 */
	protected static $_instance = null;

	/**
	 * @return Tracking_Number_In_Orders_Page
	 */
	public static function get_instance()
	{
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct()
	{
		add_filter( 'manage_edit-shop_order_columns', [$this, 'add_column_header'], 20 );
		add_action( 'manage_shop_order_posts_custom_column',[$this,  'add_tracking_number'] );

	}


	/**
	 * @param array $columns
	 *
	 * @return array
	 */
	public function add_column_header( $columns )
	{

		$new_columns = [];

		foreach ( $columns as $column_name => $column_info ) {

			$new_columns[ $column_name ] = $column_info;

			if ( 'order_date' === $column_name ) {
				$new_columns[self::COLUMN_NAME] = __( '<span class="dashicons dashicons-location"></span> Shipment Tracking', 'woocommerce-australia-post-pro' );
			}
		}

		return $new_columns;
	}


	/**
	 * @param string $column
	 */
	public function add_tracking_number( $column )
	{
		global $post;

		if ( self::COLUMN_NAME !== $column ) {
			return;
		}

		$order    = wc_get_order( $post->ID );
		$shipments = json_decode($order->get_meta(Create_Shipments_Endpoint::LABELS_SHIPMENTS_META_KEY), true);

		if (!$shipments) {
			return;
		}

		$tracking_urls = [];
		foreach ($shipments as $shipment){
			if (!isset($shipment['items'])) continue;
			foreach ($shipment['items'] as $item) {
				$tracking_urls[] = $this->tracking_url($item['tracking_details']['article_id'], $item['tracking_details']['article_id']);
			}
		}

		if (count($tracking_urls) > 0) {
			echo '<ul style="list-style: none;">';
			foreach ($tracking_urls as $tracking_url) {
				echo sprintf('<li>%s</li>', $tracking_url);
			}
			echo '</ul>';
			return;
		}

		echo '-';
	}

	/**
	 * @param $trackingNumber
	 * @param $text
	 *
	 * @return string
	 */
	private function tracking_url($trackingNumber, $text)
	{
		$tracking_url = str_replace( '{tracking_number}', trim($trackingNumber), $this->tracking_url );
		return sprintf( '<a target="_blank" href="%s">%s</a>', trim($tracking_url), $text );
	}

}
